@@ -1,10 +1,30 @@
+/* # skkinput (Simple Kana-Kanji Input)
+ *
+ * This file is part of skkinput.
+ * Copyright (C) 2002
+ * Takashi SAKAMOTO (PXG01715@nifty.ne.jp)
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2, or (at your option)
+ * any later version.
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with skkinput; see the file COPYING.  If not, write to
+ * the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+ */
 #ifndef Char_h
 #define Char_h
 
 #include "charset.h"
 
 /*========================================================================*
- *	}N̒`B
+ *	ޥ
  *========================================================================*/
 
 #define	CHAR_CHARSET(cc)			(((cc) >> 24) & 0x7F)
@@ -14,22 +34,22 @@
 #define	Char_IsEqualAscii(chl,chr)	(!Char_DifferenceAscii ((chl), (chr)))
 
 /*========================================================================*
- *	^`B
+ *	
  *========================================================================*/
 
 /*
- *	^Brbg̎gpԂ͎̒ʂB
+ *	ʸӥåȤλѾ֤ϼ̤ꡣ
  *		
  *		3130 .. 2423 .. 1615 ... 0
  *		
- *		󄫕              
- *		    W        R[h
+ *		ʸ          ʸ    
+ *		    稭        ɨ
  *		
  */
 typedef unsigned long	Char ;
 
 /*========================================================================*
- *	vg^Cv錾B
+ *	ץȥ
  *========================================================================*/
 
 Char	Char_Make (int nSet, int nCode) ;
