@@ -1,3 +1,23 @@
+/* # skkinput (Simple Kana-Kanji Input)
+ *
+ * This file is part of skkinput.
+ * Copyright (C) 2002
+ * Takashi SAKAMOTO (PXG01715@nifty.ne.jp)
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2, or (at your option)
+ * any later version.
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with skkinput; see the file COPYING.  If not, write to
+ * the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+ */
 #include "AfxWin.h"
 #include "dispatch.h"
 #include <assert.h>
@@ -37,7 +57,8 @@ static	volatile int		snNeedToRunGC ;
 void
 TLispClient_MainLoop (
 	register XtAppContext	appcontext,
-	register TLispMachine*	pTopLM)
+	register TLispMachine*	pTopLM,
+	register int			(*pGetExitFlagProc)(void))
 {
 	register Boolean		fBlock		= True ;
 	XEvent					xev ;
@@ -46,12 +67,15 @@ TLispClient_MainLoop (
 	register TLispManager*	pLispMgr	= pTopLM->m_pLispMgr ;
 #endif
 
+	assert (pTopLM != NULL) ;
+	assert (pGetExitFlagProc != NULL) ;
+
 #if defined (USE_BLOCKHOOK)
 	sfRunGC			= False ;
 	snNeedToRunGC	= 0 ;
 #endif
 
-	while (!XtAppGetExitFlag (appcontext)) {
+	while (! (*pGetExitFlagProc)()) {
 		if (fBlock) {
 			XtAppNextEvent (appcontext, &xev) ;
 			AfxDispatchEvent (&xev) ;
@@ -86,15 +110,22 @@ TLispClient_ClassInitialize (
 	register TLispMachine**	ppLM,
 	register const char*	pStrConfigPath,
 	register const char*	pStrServerHost,
-	register int			nPortNum)
+	register int			nPortNum,
+	register Boolean		fCreateLispMgr)
 {
 	TLispManager*		pLispMgr ;
 	TLispMachine*		pLM ;
 	TLispEntity*		pEntBuffer ;
 	register const char*	pPath ;
 
-	if (TFAILED (TLispMgr_Create (&pLispMgr))) 
-		return	False ;
+	if (fCreateLispMgr) {
+		if (TFAILED (TLispMgr_Create (&pLispMgr)))
+			return	False ;
+	} else {
+		if (ppLispMgr == NULL || *ppLispMgr == NULL)
+			return	False ;
+		pLispMgr	= *ppLispMgr ;
+	}
 	if (TFAILED (TLispMachine_Create (pLispMgr, NULL, &pLM)))
 		return	False ;
 
@@ -102,11 +133,12 @@ TLispClient_ClassInitialize (
 	lispMachine_InsertBuffer (pLM, pEntBuffer) ;
 	lispMachineCode_SetCurrentBuffer (pLM, pEntBuffer) ;
 
-	pPath	= (pStrConfigPath == NULL)? "." : pStrConfigPath ;
+	pPath	= (pStrConfigPath == NULL || *pStrConfigPath == '\0')? "." : pStrConfigPath ;
 	if (TFAILED (tLispClient_parseAndEval (pLM, "(setq load-path '(\"%s\"))", pPath)) ||
 		TFAILED (tLispClient_parseAndEval (pLM, "(load \"init.el\")")))
 		return	False ;
 	if (pStrServerHost != NULL &&
+		*pStrServerHost != '\0' &&
 		TFAILED (tLispClient_parseAndEval (pLM, "(setq skk-server-host \"%s\")", pStrServerHost)))
 		return	False ;
 	if (nPortNum >= 0 &&
@@ -384,12 +416,13 @@ tLispClient_createFrame (
 	 *	롣
 	 */
 	if (wgMinibufFrame != NULL) {
-		if (TFAILED (lispMgr_MakeFrame (pLispMgr, wgMinibufFrame, pEntMinibuf, pEntMinibuf, NULL, &pEntMinibufFrame)))
+		if (TFAILED (lispMgr_MakeFrame (pLispMgr, wgMinibufFrame, NULL, pEntMinibuf, NULL, &pEntMinibufFrame)))
 			return	False ;
 		if (TFAILED (lispFrame_GetTopWindow (pEntMinibufFrame, &pEntMinibufWindow)))
 			return	False ;
 		assert (pEntMinibufFrame  != NULL) ;
 		assert (pEntMinibufWindow != NULL) ;
+		//lispWindow_SetMinibufWindow (pEntMinibufWindow, True) ;
 		lispMachine_InsertFrame (pLM, pEntMinibufFrame) ;
 		XtVaSetValues (wgMinibufFrame, XtNlispFrameObject, pEntMinibufFrame, NULL) ;
 	} else {
@@ -598,6 +631,9 @@ tLispClient_parseAndEval (
 	vsnprintf (strBuffer, NELEMENTS (strBuffer) - 1, pFormat, ap) ;
 	va_end (ap) ;
 	strBuffer [NELEMENTS (strBuffer) - 1]	= '\0' ;
+#if defined (DEBUG) || 0
+	fprintf (stderr, "%s\n", strBuffer) ;
+#endif
 
 	pEntTarget	= lispMgr_ParseStringA (pLispMgr, strBuffer, strlen (strBuffer), NULL) ;
 	if (pEntTarget == NULL)
