@@ -1,3 +1,23 @@
+/* # skkinput (Simple Kana-Kanji Input)
+ *
+ * This file is part of skkinput.
+ * Copyright (C) 2002
+ * Takashi SAKAMOTO (PXG01715@nifty.ne.jp)
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2, or (at your option)
+ * any later version.
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with skkinput; see the file COPYING.  If not, write to
+ * the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+ */
 #if !defined (lispfunc_h)
 #define	lispfunc_h
 
@@ -51,9 +71,14 @@ enum {
 	LISPMGR_INDEX_BUFFER_FILE_NAME,
 	LISPMGR_INDEX_MODE_LINE_FORMAT,
 	LISPMGR_INDEX_LOAD_PATH,
+	LISPMGR_INDEX_KILL_RING,
+	LISPMGR_INDEX_KILL_REGION,
+	LISPMGR_INDEX_KILL_RING_YANK_POINTER,
+	LISPMGR_INDEX_YANK,
 
 	LISPMGR_INDEX_SKK_SERVER_HOST,
 	LISPMGR_INDEX_SKK_SERVER_LIST,
+	LISPMGR_INDEX_SKK_PORTNUM,
 	LISPMGR_INDEX_SKK_PROCESS_OKURI_EARLY,
 	LISPMGR_INDEX_J_HENKAN_KEY,
 	LISPMGR_INDEX_J_SEARCH_KEY,
@@ -262,7 +287,7 @@ Boolean	lispBuffer_GetModifiedp			(TLispManager*, TLispEntity*) ;
 void	lispBuffer_SetModifiedp			(TLispManager*, TLispEntity*, Boolean) ;
 
 /*	lispwindow.c */
-Boolean	lispMgr_CreateWindow			(TLispManager*, TLispEntity** const) ;
+Boolean	lispMgr_CreateWindow			(TLispManager*, Boolean, TLispEntity** const) ;
 void	lispMgr_DestroyWindow			(TLispManager*, TLispEntity*) ;
 Boolean	lispWindow_SetNext				(TLispEntity*, TLispEntity*) ;
 Boolean	lispWindow_SetPrevious			(TLispEntity*, TLispEntity*) ;
@@ -280,6 +305,8 @@ Boolean	lispWindow_EnableModeline		(TLispEntity*, Boolean) ;
 Boolean	lispWindow_SetMessage			(TLispManager*, TLispEntity*, TLispEntity*) ;
 Boolean	lispWindow_GetMessage			(TLispEntity*, TLispEntity** const) ;
 Boolean	lispWindow_GetViewMarker		(TLispEntity*, TLispEntity** const) ;
+Boolean	lispWindow_Minibufferp			(TLispEntity*) ;
+void	lispWindow_SetMinibufWindow		(TLispEntity*, Boolean) ;
 
 /*	lispframe.c	*/
 Boolean	lispMgr_MakeFrame				(TLispManager*, Widget, TLispEntity*, TLispEntity*, TLispEntity*, TLispEntity** const) ;
