@@ -1,3 +1,23 @@
+/* # skkinput (Simple Kana-Kanji Input)
+ *
+ * This file is part of skkinput.
+ * Copyright (C) 2002
+ * Takashi SAKAMOTO (PXG01715@nifty.ne.jp)
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2, or (at your option)
+ * any later version.
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with skkinput; see the file COPYING.  If not, write to
+ * the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+ */
 #include "local.h"
 #include <stdio.h>
 #include <assert.h>
@@ -30,7 +50,7 @@ static	Boolean	lispMachine_createShortWindowModelineString	(TVarbuffer*, TLispMa
 static	Boolean	lispMachine_addStringToWindowModeline	(TVarbuffer*, TFontSet*, int, const Char*, int) ;
 static	void	lispMachine_windowPutchar1	(TDisplayState*, Widget, const Char*, int, int) ;
 static	void	lispMachine_windowPutchar2	(TDisplayState*, Widget, const Char*, int, int) ;
-static	Boolean	lispMachine_windowHaveModelinep	(TLispMachine*, TLispEntity*, TLispEntity**) ;
+static	Boolean	lispMachine_getModelineString	(TLispMachine*, TLispEntity*, TLispEntity**) ;
 
 
 static inline	void
@@ -367,7 +387,8 @@ lispMachine_updateWindowBuffer (
 		}
 	}
 
-	fHaveModeline	= lispMachine_windowHaveModelinep (pLM, pEntBuffer, &pEntModeline) ;
+	fHaveModeline	= ! lispWindow_Minibufferp (pEntWindow) ;
+	lispMachine_getModelineString (pLM, pEntBuffer, &pEntModeline) ;
 	nRest			= nPointMax - nPoint ;
 
 	if (TFAILED (fNoFrame)) {
@@ -379,10 +400,6 @@ lispMachine_updateWindowBuffer (
 		if (rc.width <= 0 || rc.height <= 0)
 			return	False ;
 
-#if defined (DEBUG) || 0
-		fprintf (stderr, "Frame (%d, %d, %d, %d)\n",
-				 rc.x, rc.y, rc.width, rc.height) ;
-#endif
 		pFontSet		= TFrame_GetFontSet    (wgTerminal) ;
 		TFrame_GetLineSpacing (wgTerminal, &nFontHeight) ;
 
@@ -395,6 +412,10 @@ lispMachine_updateWindowBuffer (
 		fExternModeline	= TFrame_HaveExternModeline (wgTerminal) ;
 		if (!fExternModeline && fHaveModeline)
 			nLines	-- ;
+#if defined (DEBUG) || 0
+		fprintf (stderr, "Frame: Rect(%d, %d, %d, %d), ExtMod(%d), Mod(%d), Line(%d), Buffer(%p)\n",
+				 rc.x, rc.y, rc.width, rc.height, fExternModeline, fHaveModeline, nLines, pEntBuffer) ;
+#endif
 
 		if (!fVariable || nRest > 0) {
 			arg.m_nLines		= nLines ;
@@ -439,7 +460,7 @@ lispMachine_updateWindowMessage (
 	Widget						wgTerminal ;
 	TLispEntity*				pEntMessage ;
 	TLispEntity*				pEntBuffer ;
-	TLispEntity*				pEntModeline ;
+	TLispEntity*				pEntModeline	= NULL ;
 	XRectangle					rc ;
 	register Boolean			fHaveModeline, fHaveFocus, fVariable, fExternModeline ;
 	int							nPoint, nPointMax, nLength, nCursor ;
@@ -490,9 +511,12 @@ lispMachine_updateWindowMessage (
 	nGuessChar		= rc.width / nFontHeight ;
 	nRest			= nPointMax - nPoint ;
 	nLines			= rc.height / nFontHeight ;
-	fHaveModeline	= lispMachine_windowHaveModelinep (pLM, pEntBuffer, &pEntModeline) ;
-	if (!fExternModeline && fHaveModeline)
-		nLines	-- ;
+	fHaveModeline	= ! lispWindow_Minibufferp (pEntWindow) ;
+	if (fHaveModeline) {
+		lispMachine_getModelineString (pLM, pEntBuffer, &pEntModeline) ;
+		if (!fExternModeline)
+			nLines	-- ;
+	}
 	ptr			= pBufString + nPoint ;
 
 	while ((fVariable || nLines > 0) && nRest > 0) {
@@ -640,7 +664,7 @@ lispMachine_windowPutchar2 (
 }
 
 Boolean
-lispMachine_windowHaveModelinep (
+lispMachine_getModelineString (
 	register TLispMachine*	pLM,
 	register TLispEntity*	pEntBuffer,
 	register TLispEntity**	ppEntModelineFormat)
@@ -648,13 +672,21 @@ lispMachine_windowHaveModelinep (
 	register TLispManager*	pLispMgr	= pLM->m_pLispMgr ;
 	register TLispEntity*	pEntTarget ;
 	TLispEntity*			pEntRetval ;
-	register Boolean			fRetval ;
+	register Boolean		fRetval ;
+
+	assert (pLM != NULL) ;
+	assert (pLispMgr != NULL) ;
+	assert (pEntBuffer != NULL) ;
+	assert (ppEntModelineFormat != NULL) ;
 
 	pEntTarget	= lispMgr_GetReservedEntity (pLispMgr, LISPMGR_INDEX_MODE_LINE_FORMAT) ;
 	fRetval		= lispMachine_GetSymbolValue (pLM, pEntBuffer, pEntTarget, &pEntRetval) ;
-	if (TFAILED (fRetval) || TSUCCEEDED (lispEntity_Nullp (pLispMgr, pEntRetval)))
+	if (TFAILED (fRetval) || TSUCCEEDED (lispEntity_Nullp (pLispMgr, pEntRetval))) {
+		lispMgr_CreateNil (pLispMgr, ppEntModelineFormat) ;
 		return	False ;
-	*ppEntModelineFormat	= pEntRetval ;
+	} else {
+		*ppEntModelineFormat	= pEntRetval ;
+	}
 	return	True ;
 }
 
