@@ -1,3 +1,23 @@
+/* # skkinput (Simple Kana-Kanji Input)
+ *
+ * This file is part of skkinput.
+ * Copyright (C) 2002
+ * Takashi SAKAMOTO (PXG01715@nifty.ne.jp)
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2, or (at your option)
+ * any later version.
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with skkinput; see the file COPYING.  If not, write to
+ * the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+ */
 #include "local.h"
 #include <stdio.h>
 #include <assert.h>
@@ -18,6 +38,7 @@ static	Boolean	lispMachine_computeHenkanVectors (TLispMachine*, const Char*, int
 static	Boolean	lispMachine_jVectorAdd (TLispMachine*, TLispEntity*, TLispEntity*, TLispEntity**) ;
 static	Boolean	lispMachine_jVectorMem (TLispMachine*, TLispEntity*, TLispEntity*, Boolean*) ;
 static	Boolean	lispMachine_getSkkServerList (TLispMachine*, TLispEntity**) ;
+static	Boolean	lispMachine_getSkkPortnum (TLispMachine*, int*) ;
 
 TLMRESULT
 lispMachineState_JSearchServer (
@@ -29,11 +50,14 @@ lispMachineState_JSearchServer (
 	TLispEntity*				pValServerListOrg ;
 	register TLMRESULT			lmResult	= LMR_RETURN ;
 	TLispEntity*				pEntRetval ;
+	int							nSkkPort ;
 
 	if (TFAILED (lispMachine_getSkkServerList (pLM, &pValServerListOrg))) {
 		lispMachineCode_SetError (pLM) ;
 		return	LMR_RETURN ;
 	}
+	(void) lispMachine_getSkkPortnum (pLM, &nSkkPort) ;
+
 	pJisyo				= NULL ;
 	pEntRetval			= NULL ;
 	pValServerList		= pValServerListOrg ;
@@ -55,7 +79,7 @@ lispMachineState_JSearchServer (
 
 		pJisyo	= SkkServerJisyo_Find (pStrHost, nStrHost) ;
 		if (pJisyo == NULL) 
-			pJisyo	= SkkServerJisyo_Register (pStrHost, nStrHost, 1178) ;
+			pJisyo	= SkkServerJisyo_Register (pStrHost, nStrHost, nSkkPort /*1178*/) ;
 
 		if (pJisyo != NULL) {
 			if (TFAILED (lispMachine_jSearchServerSubr (pLM, pJisyo, &pEntRetval))) {
@@ -722,8 +746,12 @@ lispMachine_getSkkServerList (
 	pEntServerHost	= lispMgr_GetReservedEntity (pLispMgr, LISPMGR_INDEX_SKK_SERVER_HOST) ;
 	if (TFAILED (lispMachine_GetCurrentSymbolValue (pLM, pEntServerHost, &pValServerHost)) ||
 		TSUCCEEDED (lispEntity_Voidp (pLispMgr, pValServerHost)) ||
-		TSUCCEEDED (lispEntity_Nullp (pLispMgr, pValServerHost)))
+		TSUCCEEDED (lispEntity_Nullp (pLispMgr, pValServerHost))) 
 		goto	exit_func ;
+#if defined (DEBUG)
+	lispEntity_Print (pLispMgr, pEntServerHost) ;
+	lispEntity_Print (pLispMgr, pValServerHost) ;
+#endif
 
 	if (TFAILED (lispMgr_CreateNil (pLispMgr, &pEntNil)) ||
 		TFAILED (lispMgr_CreateConscell (pLispMgr, pValServerHost, pEntNil, &pEntity)) ||
@@ -733,7 +761,7 @@ lispMachine_getSkkServerList (
  exit_func:
 	assert (pValServerList != NULL) ;
 	lispEntity_AddRef (pLispMgr, pValServerList) ;
-#if defined (DEBUG)
+#if defined (DEBUG) || 0
 	fprintf (stderr, "skk-server-list = ") ;
 	lispEntity_Print (pLispMgr, pValServerList) ;
 	fprintf (stderr, "\n") ;
@@ -742,3 +770,28 @@ lispMachine_getSkkServerList (
 	return	True ;
 }
 
+Boolean
+lispMachine_getSkkPortnum (
+	register TLispMachine*	pLM,
+	register int*			pnSkkPort)
+{
+	register TLispManager*	pLispMgr ;
+	register int			nPort	= 1178 ;
+	register TLispEntity*	pEntSkkPortnum ;
+	TLispEntity*			pValSkkPortnum ;
+	long					lPort	= 1178 ;
+
+	assert (pLM != NULL) ;
+	pLispMgr	= pLM->m_pLispMgr ;
+
+	pEntSkkPortnum	= lispMgr_GetReservedEntity (pLispMgr, LISPMGR_INDEX_SKK_PORTNUM) ;
+	assert (pEntSkkPortnum != NULL) ;
+	if (TSUCCEEDED (lispMachine_GetCurrentSymbolValue (pLM, pEntSkkPortnum, &pValSkkPortnum)) &&
+		TSUCCEEDED (lispEntity_GetIntegerValue (pLispMgr, pValSkkPortnum, &lPort))) {
+		nPort	= (int) lPort ;
+	}
+	if (pnSkkPort != NULL)
+		*pnSkkPort	= nPort ;
+	return	TRUE ;
+}
+
