@@ -1,3 +1,23 @@
+/* # skkinput (Simple Kana-Kanji Input)
+ *
+ * This file is part of skkinput.
+ * Copyright (C) 2002
+ * Takashi SAKAMOTO (PXG01715@nifty.ne.jp)
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2, or (at your option)
+ * any later version.
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with skkinput; see the file COPYING.  If not, write to
+ * the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+ */
 #include <assert.h>
 #include "Char.h"
 #include "kanji.h"
@@ -77,6 +97,7 @@ static	int		ctextEscapeSequenceState5			(PCTEXTSTATE, int) ;
 static	int		ctextEscapeSequenceState6			(PCTEXTSTATE, int) ;
 static	int		ctextEscapeSequenceDefault			(PCTEXTSTATE, int) ;
 static	int		rtransferCompoundTextStateMachine	(PKANJISTATEMACHINE, Char, char*) ;
+static	int		initializeCompoundTextStateMachine	(PKANJISTATEMACHINE) ;
 
 
 /*========================================================================
@@ -93,6 +114,12 @@ InitializeKanjiFiniteStateMachine (
 	register PKANJISTATEMACHINE	pKSM,
 	register int				iCodingSystem)
 {
+	static	int		(*pInitializeFuncTbl [])(PKANJISTATEMACHINE pKSM)	= {
+		restartEucJpStateMachine,
+		restartIso2022JpStateMachine,
+		restartShiftJisStateMachine,
+		initializeCompoundTextStateMachine,
+	} ;
 	static	int		(*pRestartFuncTbl [])(PKANJISTATEMACHINE pKSM)	= {
 		restartEucJpStateMachine,
 		restartIso2022JpStateMachine,
@@ -118,7 +145,7 @@ InitializeKanjiFiniteStateMachine (
 	pKSM->m_pRestartFunc	= pRestartFuncTbl   [iCodingSystem] ;
 	pKSM->m_pTransferFunc	= pTransferFuncTbl  [iCodingSystem] ;
 	pKSM->m_pRtransferFunc	= pRtransferFuncTbl [iCodingSystem] ;
-	return	(pKSM->m_pRestartFunc)(pKSM) ;
+	return	(pInitializeFuncTbl [iCodingSystem])(pKSM) ;
 }
 
 /*
@@ -434,8 +461,8 @@ rtransferEucJpStateMachine (
 	switch (Char_Charset (cc)) {
 	case	KCHARSET_JISX0208_1978:
 	case	KCHARSET_JISX0208_1983:
-		*pOutput	++	= (char)(Char_Code (cc) >> 8) ;
-		*pOutput	++	= (char)(Char_Code (cc) >> 0) ;
+		*pOutput	++	= (char)((Char_Code (cc) >> 8) | 0x80) ;
+		*pOutput	++	= (char)((Char_Code (cc) >> 0) | 0x80) ;
 		return	2 ;
 
 	case	KCHARSET_JISX0201_1976:
@@ -450,8 +477,8 @@ rtransferEucJpStateMachine (
 
 	case	KCHARSET_JISX0212_1990:
 		*pOutput	++	= '\x8F' ;
-		*pOutput	++	= (char)(Char_Code (cc) >> 8) ;
-		*pOutput	++	= (char)(Char_Code (cc) >> 0) ;
+		*pOutput	++	= (char)((Char_Code (cc) >> 8) | 0x80) ;
+		*pOutput	++	= (char)((Char_Code (cc) >> 0) | 0x80) ;
 		return	3 ;
 
 	default:
@@ -1137,6 +1164,23 @@ rtransferShiftJisStateMachine (
 /*========================================================================*
  *	CompoundText ν˴ؤؿ
  *========================================================================*/
+int
+initializeCompoundTextStateMachine (
+	register PKANJISTATEMACHINE	pKSM)
+{
+	register PCTEXTSTATE	pState ;
+
+	assert (pKSM != NULL) ;
+	pState						= &pKSM->m_state.m_ctext ;
+	pState->m_fEscapeSequence	= False ;
+	pState->m_iEscapeState		= CTEXTSTATE_ESCAPE ;
+	pState->m_iLeadChara		= '\0' ;
+	pState->m_fSingleShift		= False ;
+	pState->m_nGL 				= KCHARSET_NOTHING ;	/* GL, GR γƤɬǡ*/
+	pState->m_nGR 				= KCHARSET_NOTHING ;
+	return	True ;
+}
+
 int
 restartCompoundTextStateMachine (
 	register PKANJISTATEMACHINE	pKSM)
