@@ -1,3 +1,23 @@
+/* # skkinput (Simple Kana-Kanji Input)
+ *
+ * This file is part of skkinput.
+ * Copyright (C) 2002
+ * Takashi SAKAMOTO (PXG01715@nifty.ne.jp)
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2, or (at your option)
+ * any later version.
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with skkinput; see the file COPYING.  If not, write to
+ * the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+ */
 #include "local.h"
 #include <ctype.h>
 #include <assert.h>
@@ -262,7 +282,7 @@ static	Boolean	parseBackslashedChar	(const char**, int*, Char*) ;
 static	int		parseKeyString	(Display*, const char**, int*, KeySym*, unsigned int*, int) ;
 static	int		parseKeySymbol	(Display*, const char**, int*, KeySym*, unsigned int*, int) ;
 
-/*	$BFs$D0J>e$N%-!<$,2!$5$l$?>l9g$K$O(B 100% $B$NJ]>Z$O$G$-$J$$!#(B
+/*	İʾΥ줿ˤ 100% ݾڤϤǤʤ
  */
 static inline Boolean
 ascii2keysym (
@@ -281,7 +301,7 @@ ascii2keysym (
 	assert (puStateRet != NULL) ;
 
 	if (ch == 0x7F) {
-		/* $B@5$7$$$H$O8B$i$J$$$I$3$m$+!"$+$J$j2x$7$$$1$I!#(B*/
+		/* Ȥϸ¤ʤɤʤɡ*/
 		keysym	= XK_Delete ;
 		uState	= 0 ;
 	} else {
@@ -389,7 +409,7 @@ string2keysym (
 	register int			i, nTarget, nMin, nMax, nCmp ;
 	register unsigned int	uState ;
 
-	/*	$B$^$:$O(B state $B$r8+$F!"(B
+	/*	ޤ state 򸫤ơ
 	 */
 	uState	= 0 ;
 	while (*(pString + 0) != '\0' &&
@@ -406,7 +426,7 @@ string2keysym (
 	if (*pString == '\0')
 		return	False ;
 
-	/*	$B<!$K(B symbol $B$r8+$k!#(B
+	/*	 symbol 򸫤롣
 	 */
 	ksym	= XStringToKeysym (pString) ;
 	if (ksym != NoSymbol) 
@@ -653,7 +673,7 @@ string2keysymlist (
 }
 
 /*
- *	$BB3$/J8;zNs$O(B STRING $B$G$"$k!#(B
+ *	³ʸ STRING Ǥ롣
  */
 int
 parseKeyString (
@@ -703,7 +723,7 @@ parseKeyString (
 	*ppString	= pString ;
 	*pnString	= nString ;
 
-	/*	$B2?%7%s%\%k;H$C$?$+$rJV$9!#(B*/
+	/*	ܥȤä֤*/
 	return	(nKeysym == 0)? nLength : (nKeysym - nDest) ;
 }
 
@@ -786,7 +806,7 @@ parseBackslashedChar (
 	if (nString <= 0)
 		return	False ;
 
-	/*	$B$3$N;~E@$G(B '\\' $B$rFI$_=*$($?<!$N>uBV$K$"$k!#(B*/
+	/*	λ '\\' ɤ߽ξ֤ˤ롣*/
 	cc	= *pString ++ ;
 	nString	-- ;
 	switch (cc) {
