@@ -1,3 +1,23 @@
+/* # skkinput (Simple Kana-Kanji Input)
+ *
+ * This file is part of skkinput.
+ * Copyright (C) 2002
+ * Takashi SAKAMOTO (PXG01715@nifty.ne.jp)
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2, or (at your option)
+ * any later version.
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with skkinput; see the file COPYING.  If not, write to
+ * the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+ */
 #include "AfxWin.h"
 #include "dispatch.h"
 #include <assert.h>
@@ -731,8 +751,16 @@ kinputClient_onKeyNotify (
 
 	wndFocus	= (pClient->m_wndFocus != None)? pClient->m_wndFocus : pClient->m_wndRequestor ;
 	if (!pEv->m_fChar) {
+		register XEvent*	pXEv	= pEv->u.m_pEv ;
+		register Window		wndWindowBak, wndSubwindowBak ;
 		assert (pEv->u.m_pEv != NULL) ;
-		XSendEvent (pDisplay, wndFocus, True, KeyPressMask, pEv->u.m_pEv) ;
+		wndWindowBak			= pXEv->xkey.window ;
+		wndSubwindowBak			= pXEv->xkey.subwindow ;
+		pXEv->xkey.window		= pClient->m_wndRequestor ;
+		pXEv->xkey.subwindow	= None ;
+		XSendEvent (pDisplay, wndFocus, True, KeyPressMask, pXEv) ;
+		pXEv->xkey.window		= wndWindowBak ;
+		pXEv->xkey.window		= wndSubwindowBak ;
 		return ;
 	}
 	cc	= pEv->u.m_ch ;
