@@ -1,3 +1,23 @@
+/* # skkinput (Simple Kana-Kanji Input)
+ *
+ * This file is part of skkinput.
+ * Copyright (C) 2002
+ * Takashi SAKAMOTO (PXG01715@nifty.ne.jp)
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2, or (at your option)
+ * any later version.
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with skkinput; see the file COPYING.  If not, write to
+ * the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+ */
 #if !defined (KinputClientP_h)
 #define	KinputClientP_h
 
@@ -37,7 +57,7 @@ enum {
 struct tagKinputClient {
 	TLispClient				m_LispClient ;
 	Widget					m_wgProtocol ;
-	Window					m_wndRequestor ;	/* $BJQ49MW5a$r=P$7$?(B Window */
+	Window					m_wndRequestor ;	/* Ѵ׵Ф Window */
 	Widget					m_wgTopFrame ;
 	Boolean					m_fReserve ;
 	Boolean					m_fProbe ;
