@@ -1,3 +1,23 @@
+/* # skkinput (Simple Kana-Kanji Input)
+ *
+ * This file is part of skkinput.
+ * Copyright (C) 2002
+ * Takashi SAKAMOTO (PXG01715@nifty.ne.jp)
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2, or (at your option)
+ * any later version.
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with skkinput; see the file COPYING.  If not, write to
+ * the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+ */
 #include "AfxWin.h"
 #include <stdio.h>
 #include <X11/Intrinsic.h>
@@ -911,9 +931,6 @@ toverTheSpotWindow_onSetPAttributeSpotLocation (
 	pTerminal	= &wgThis->toverwin.m_Terminal ;
 	nControl	= TVarbuffer_GetUsage (&pTerminal->m_vbufControl) ;
 	nText		= TVarbuffer_GetUsage (&pTerminal->m_vbufText) ;
-#if defined (DEBUG) || 0
-	fprintf (stderr, "SpotLocation: (%d, %d), %d, %d\n", x, y, nControl, nText) ;
-#endif
 	/* Spot ѹ ReConfigure ɬפˤĤʤ롣*/
 	fMove	= (wgThis->toverwin.m_ptSpot.x != x || wgThis->toverwin.m_ptSpot.y != y) ;
 	wgThis->toverwin.m_ptSpot.x	= x ;
@@ -921,6 +938,16 @@ toverTheSpotWindow_onSetPAttributeSpotLocation (
 
 	if (wgThis->toverwin.m_wndModeshell != None && fMove &&
 		wgThis->toverwin.m_fFloatingModeshell) {
+		register TFontSet*	pFontSet	= &wgThis->toverwin.m_fsTerminal ;
+		register int		nAscent, nDescent, nFontHeight ;
+		register Boolean	fLineSpacing ;
+		int					nLineSpacing ;
+
+		fLineSpacing	= toverTheSpotWindow_getPreeditLineSpacing (gw, &nLineSpacing) ;
+		nDescent		= TFontSet_GetDescent (pFontSet) ;
+		nAscent			= TFontSet_GetAscent  (pFontSet) ;
+		nFontHeight		= TFontSet_GetHeight  (pFontSet) ;
+		y	+= (fLineSpacing && nFontHeight < nLineSpacing)? (nLineSpacing - nAscent) : nDescent ;
 		XMoveWindow (XtDisplay (gw), wgThis->toverwin.m_wndModeshell, x, y) ;
 	}
 	return	fMove && (nControl > 0 && nText > 0) ;
@@ -1686,7 +1713,7 @@ toverTheSpotWindow_configureTerminalWindow (
 		nMasterClientAreaWidth	= 65535 ;
 	}
 	nX					= wgThis->toverwin.m_ptSpot.x + nClientAreaX ;
-	nY					= wgThis->toverwin.m_ptSpot.y + nClientAreaY - pFontSet->m_iAscent ;
+	nY					= wgThis->toverwin.m_ptSpot.y + nClientAreaY - TFontSet_GetAscent (pFontSet) ;
 #if defined (DEBUG) || 0
 	fprintf (stderr, "Spot:(%d, %d) Client:(%d, %d, %d, %d), line=%d\n",
 			 wgThis->toverwin.m_ptSpot.x,
@@ -1768,11 +1795,16 @@ toverTheSpotWindow_configureTerminalWindow (
 
 		if (nMaxWindow <= 1) {
 			nX	=  wgThis->toverwin.m_ptSpot.x + nClientAreaX ;
-			if (fEmpty)
-				nY	+= nLineSpacing ;
+			if (fEmpty) {
+				register int	nFontHeight	= TFontSet_GetHeight (pFontSet) ;
+				nY	+= (fLineSpacing && nFontHeight < nLineSpacing)? nLineSpacing : nFontHeight ;
+			}
 		} else {
 			nX	= nClientAreaX ;
 		}
+#if defined (DEBUG)
+		fprintf (stderr, "spot(x,y,ls,empty)=(%d,%d,%d,%d)\n", nX, nY, nLineSpacing, fEmpty) ;
+#endif
 		XMoveWindow (pDisplay, wgThis->toverwin.m_wndModeshell, nX, nY) ;
 	}
 	return ;
