@@ -1,3 +1,23 @@
+/* # skkinput (Simple Kana-Kanji Input)
+ *
+ * This file is part of skkinput.
+ * Copyright (C) 2002
+ * Takashi SAKAMOTO (PXG01715@nifty.ne.jp)
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2, or (at your option)
+ * any later version.
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with skkinput; see the file COPYING.  If not, write to
+ * the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+ */
 #include "AfxWin.h"
 #include "local.h"
 #include <stdio.h>
@@ -121,6 +141,9 @@ ximServer_onInitialize (
 	register XIMServerWidget	wgThis		= (XIMServerWidget) gnew ;
 	register Display*			pDisplay	= XtDisplay (gnew) ;
 
+#if defined (DEBUG)
+	fprintf (stderr, "ximServer_onInitizlize (%p)\n", wgThis) ;
+#endif
 	TVarbuffer_Initialize (&wgThis->ximServer.m_vbufClient, sizeof (Widget)) ;
 #define MakeAtom(s)	XInternAtom(pDisplay,s,False)
 	wgThis->ximServer.m_atServer		= MakeAtom ("@server=" XIM_SERVER_NAME) ;
@@ -180,6 +203,9 @@ ximServer_onDestroy (
 {
 	register XIMServerWidget	wgThis	= (XIMServerWidget) gw ;
 
+#if defined (DEBUG)
+	fprintf (stderr, "ximServer_onDestroy (%p)\n", gw) ;
+#endif
 	XtCallCallbacks (gw, XtNdestroyCallback, 0) ;
 	ximServer_destroyAllClient (gw) ;
 
@@ -321,11 +347,9 @@ ximServer_onClientMessage (
 		return ;
 
 	wndClient	= (Window) pEvent->data.l [0] ;
-#if defined (DEBUG)
-	fprintf (stderr, "ximServer_onConversionRequest (window:%lx)\n", wndClient) ;
-#endif
-	if (!ximServer_isValidWindow (XtDisplay (gw), wndClient))
+	if (!ximServer_isValidWindow (XtDisplay (gw), wndClient)) {
 		return ;
+	}
 	wgClient		= ximServer_findClient (gw, wndClient) ;
 	if (wgClient == NULL) {
 		wgClient	= ximServer_newClient (gw, wndClient) ;
@@ -350,6 +374,10 @@ ximServer_onClientDestroy (
 	register XtPointer	call_data)
 {
 	register Widget		wgServer	= (Widget) closure ;
+
+#if defined (DEBUG)
+	fprintf (stderr, "ximServer_removeClient (%p, %p)\n", wgServer, call_data) ;
+#endif
 	ximServer_removeClient (wgServer, call_data) ;
 	return ;
 }
@@ -492,9 +520,10 @@ ximServer_newClient (
 	register Widget		gw,
 	register Window		wndClient)
 {
-	Arg				rArg [8] ;
-	register Widget	wgClient ;
-	register int	nArg ;
+	register XIMServerWidget	wgThis		= (XIMServerWidget) gw ;
+	Widget						wgClient ;
+	Arg							rArg [8] ;
+	register int				nArg ;
 
 	nArg	= 0 ;
 	XtSetArg (rArg [nArg], XtNmappedWhenManaged, False) ;	nArg ++ ;
@@ -503,6 +532,10 @@ ximServer_newClient (
 	wgClient	= XtCreateWidget ("ximClient", ximClientWidgetClass, gw, rArg, nArg) ;
 	if (wgClient == NULL)
 		return	NULL ;
+	if (TFAILED (TVarbuffer_Add (&wgThis->ximServer.m_vbufClient, &wgClient, 1))) {
+		XtDestroyWidget (wgClient) ;
+		return	NULL ;
+	}
 	XtAddCallback (wgClient, XtNdestroyCallback, ximServer_onClientDestroy, gw) ;
 	XtRealizeWidget (wgClient) ;
 	return	wgClient ;
@@ -560,6 +593,7 @@ ximServer_destroyAllClient (
 
 	pClient	= TVarbuffer_GetBuffer (&wgThis->ximServer.m_vbufClient) ;
 	nClient	= TVarbuffer_GetUsage  (&wgThis->ximServer.m_vbufClient) ;
+
 	/*	remoteClient ƤӽФʤ褦դ롣*/
 	while (nClient -- > 0) {
 		XtRemoveAllCallbacks (*pClient, XtNdestroyCallback) ;
